FirebaseDatabaseService class

Inheritance

Constructors

FirebaseDatabaseService({required IFirebaseDatabaseDriver firebaseDatabaseDriver})

Properties

firebaseDatabaseDriver IFirebaseDatabaseDriver
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

docDelete({required String document, required String id}) Future<Either<Exception, Unit>>
override
docGet({required String doc, required String document}) Future<Either<Exception, DataSnapshot>>
override
docSet({required Map<String, dynamic> data, required String document, String? id}) Future<Either<Exception, Unit>>
override
docUpdate({required String id, required String document, required Map<String, dynamic> data}) Future<Either<Exception, Unit>>
override
getDocument({required QuerySnapshotFiltersEntity filters}) Future<Either<Exception, DataSnapshot>>
override
getDocumentStream({required QuerySnapshotFiltersEntity filters}) Future<Either<Exception, Stream<DatabaseEvent>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited