onConfigUpdated property
Starts listening for real-time config updates from the Remote Config backend and automatically fetches updates from the RC backend when they are available.
On web, you must call fetchAndActivate before listening to this stream. Events will only be received after an initial call to fetchAndActivate.
Note: Real-time config updates are not yet supported on Windows and other desktop platforms by the Firebase C++ SDK. The listener will be registered but no events will be received. Use fetchAndActivate to manually check for updates on desktop platforms.
If a connection to the Remote Config backend is not already open, calling this method will open it. Multiple listeners can be added by calling this method again, but subsequent calls reuse the same connection to the backend.
Implementation
Stream<RemoteConfigUpdate> get onConfigUpdated {
return _delegate.onConfigUpdated;
}