ICrashLogService class abstract

Implementers

Constructors

ICrashLogService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({Map<String, dynamic>? params}) Future<Either<Exception, Unit>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setError({required dynamic exception, StackTrace? stackTrace, bool fatal = false}) Future<Either<Exception, Unit>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited