IFirebaseNotificationsService class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configure(
{bool setForegroundMessageAlert = true, dynamic onMessage(ReceivedNotificationEntity)?, dynamic onMessageOpenedApp(ReceivedNotificationEntity)?}) → Future< Either< Exception, Unit> > -
getToken(
) → Future< Either< Exception, String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveToken(
{required String userId, String collection}) → Future< Either< Exception, Unit> > -
subscribeToTopic(
{required String topic}) → Future< Either< Exception, Unit> > -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribeFromTopic(
{required String topic}) → Future< Either< Exception, Unit> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited