LocalNotificationsDriver class

Inheritance

Constructors

LocalNotificationsDriver()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({dynamic onMessageOpenedApp(ReceivedNotificationEntity message)?}) Future<Either<Exception, Unit>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() Future<Either<Exception, Unit>>
override
scheduleNotification() Future<Either<Exception, Unit>>
override
showNotification({required ReceivedNotificationEntity notification}) Future<Either<Exception, Unit>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited