PackageInfoEntity class

Implementers

Constructors

PackageInfoEntity({required String name, required String appName, required String version, required int buildNumber, required bool forceUpdate, required String buildSignature})

Properties

appName String
final
buildNumber int
final
buildSignature String
final
forceUpdate bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

getExtendedVersionNumber(String version) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited